@@ -1,3 +1,3 @@
 from sflux.client import Client
-from sflux.utils import ROW, or_, and_
+from sflux.utils import ROW, ACC, or_, and_
 from sflux.measurement import Measurement
